# processamento_imagem

Description. 
The processamento-imagem is used to:
	Processing:
		-Histogram matching
		-Structural similarity
		-Resize image
	Utils:
		-Read image
		-Save image
		-Plot image
		-Plot result
		-Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install processamento_imagem

```bash
pip install processamento_imagem
```

## Author
Marcelo Goulart Lima

## License
[MIT](https://choosealicense.com/licenses/mit/)